@@ -1,4 +1,4 @@
 from .analyzer import note_to_chord
 from .chord import Chord
 from .progression import ChordProgression
-from .quality import Quality
+from .quality import Quality, QualityManager
