@@ -1,11 +1,6 @@
-# -*- coding, utf-8 -*-
-
-from collections import OrderedDict
-
-QUALITY_DICT = OrderedDict((
+DEFAULT_QUALITIES = [
     # chords consist of 2 notes
     ('5', (0, 7)),
-    ('sus', (0, 7)),
     # 3 notes
     ('', (0, 4, 7)),
     ('maj', (0, 4, 7)),
@@ -16,6 +11,7 @@ QUALITY_DICT = OrderedDict((
     ('aug', (0, 4, 8)),
     ('sus2', (0, 2, 7)),
     ('sus4', (0, 5, 7)),
+    ('sus', (0, 5, 7)),
     # 4 notes
     ('6', (0, 4, 7, 9)),
     ('7', (0, 4, 7, 10)),
@@ -78,4 +74,4 @@ QUALITY_DICT = OrderedDict((
     ('13#9', (0, 4, 7, 10, 15, 21)),
     ('13+11', (0, 4, 7, 10, 18, 21)),
     ('13#11', (0, 4, 7, 10, 18, 21)),
-))
+]
